# thmcli
[![PyPI version](https://badge.fury.io/py/thmcli.svg)](https://badge.fury.io/py/thmcli)  
TryHackMe CLI

## Installation
```sh
pip install thmcli
```

## Usage
```
$ thm
```

## Contributing
You're welcome to create Issues/Pull Requests with features you'd want to see

## License
[MIT LICENSE](https://github.com/szymex73/py-thmapi/blob/master/LICENSE)
